@@ -135,7 +135,10 @@ def FormBuilderHelpText():
     {Fore.green_yellow}**{Fore.light_magenta}wednesday - {Fore.orange_red_1}WARNING:{Fore.light_cyan} of this week only{Style.reset}
     {Fore.green_yellow}**{Fore.light_magenta}thursday - {Fore.orange_red_1}WARNING:{Fore.light_cyan} of this week only{Style.reset}
     {Fore.green_yellow}**{Fore.light_magenta}friday - {Fore.orange_red_1}WARNING:{Fore.light_cyan} of this week only{Style.reset}
+    
 
+    {Fore.green_yellow}**{Fore.light_magenta}ff,finish{Fore.orange_red_1}WARNING:{Fore.light_cyan}finish and return without review{Style.reset}
+    {Fore.green_yellow}**{Fore.light_magenta}f,finalize{Fore.orange_red_1}WARNING:{Fore.light_cyan}finish and return with review{Style.reset}
     '''
     print(msg)
 
@@ -148,6 +151,8 @@ def FormBuilderMkText(text,data,passThru=[],PassThru=True,alternative_false=None
         if PassThru:
             if text in ['f','m','p','d']:
                 return text
+            if text in passThru:
+                return text
         if text == '':
             return 'd'
         value=None
